==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QPagedPaintDevice_Margins_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qpagedpaintdevice.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPagedPaintDevice_Margins(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPagedPaintDevice::Margins")
    QPagedPaintDevice::Margins *_ptr = reinterpret_cast<QPagedPaintDevice::Margins *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QPagedPaintDevice_Margins_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QPagedPaintDevice::Margins *__qt_this = new(__qtjambi_ptr) QPagedPaintDevice::Margins();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QPagedPaintDevice::Margins
void __qt_destruct_QPagedPaintDevice_Margins(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPagedPaintDevice::Margins")
    reinterpret_cast<QPagedPaintDevice::Margins*>(ptr)->~Margins();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPagedPaintDevice::Margins::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_initialize_1native__Lio_qt_gui_QPagedPaintDevice_00024Margins_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPagedPaintDevice::Margins::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPagedPaintDevice_Margins_0, sizeof(QPagedPaintDevice::Margins), typeid(QPagedPaintDevice::Margins), false, &deleter_QPagedPaintDevice_Margins, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_setBottom_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble bottom0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->bottom = static_cast<qreal>(bottom0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_bottom_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->bottom;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_setLeft_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble left0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->left = static_cast<qreal>(left0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_left_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->left;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_setRight_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble right0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->right = static_cast<qreal>(right0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_right_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->right;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_setTop_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble top0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->top = static_cast<qreal>(top0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_top_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->top;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPagedPaintDevice_Margins(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPagedPaintDevice::Margins>("QPagedPaintDevice::Margins", "io/qt/gui/QPagedPaintDevice$Margins");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPagedPaintDevice_Margins, {
        ConstructorInfo(&__qt_construct_QPagedPaintDevice_Margins_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPagedPaintDevice_Margins);
    registerMetaType<QPagedPaintDevice::Margins>("QPagedPaintDevice::Margins");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QPagedPaintDevice_Margins_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qpagedpaintdevice.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPagedPaintDevice_Margins(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPagedPaintDevice::Margins")
    QPagedPaintDevice::Margins *_ptr = reinterpret_cast<QPagedPaintDevice::Margins *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new Margins()
void __qt_construct_QPagedPaintDevice_Margins(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Margins()")
    Q_UNUSED(__java_arguments)
    QPagedPaintDevice::Margins *__qt_this = new(__qtjambi_ptr) QPagedPaintDevice::Margins();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QPagedPaintDevice::Margins::Margins()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_initialize_1native__Lio_qt_gui_QPagedPaintDevice_00024Margins_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPagedPaintDevice::Margins::Margins()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPagedPaintDevice_Margins, sizeof(QPagedPaintDevice::Margins), typeid(QPagedPaintDevice::Margins), false, &deleter_QPagedPaintDevice_Margins, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new Margins(QPagedPaintDevice::Margins)
void __qt_construct_QPagedPaintDevice_Margins_cref_QPagedPaintDevice_Margins(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Margins(QPagedPaintDevice::Margins)")
    jobject other0 = __java_arguments[0].l;
    const QPagedPaintDevice::Margins& __qt_other0 = qtjambi_cast<const QPagedPaintDevice::Margins& >(__jni_env, other0);
    QPagedPaintDevice::Margins *__qt_this = new(__qtjambi_ptr) QPagedPaintDevice::Margins(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPagedPaintDevice::Margins::Margins(QPagedPaintDevice::Margins)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_initialize_1native__Lio_qt_gui_QPagedPaintDevice_00024Margins_2Lio_qt_gui_QPagedPaintDevice_00024Margins_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPagedPaintDevice::Margins::Margins(QPagedPaintDevice::Margins)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPagedPaintDevice_Margins_cref_QPagedPaintDevice_Margins, sizeof(QPagedPaintDevice::Margins), typeid(QPagedPaintDevice::Margins), false, &deleter_QPagedPaintDevice_Margins, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new Margins{qreal,qreal,qreal,qreal}
void __qt_construct_QPagedPaintDevice_Margins_qreal_qreal_qreal_qreal(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct Margins{qreal,qreal,qreal,qreal}")
    jdouble left0 = __java_arguments[0].d;
    Q_UNUSED(left0)
    jdouble right1 = __java_arguments[1].d;
    Q_UNUSED(right1)
    jdouble top2 = __java_arguments[2].d;
    Q_UNUSED(top2)
    jdouble bottom3 = __java_arguments[3].d;
    Q_UNUSED(bottom3)
    QPagedPaintDevice::Margins *__qt_this = new(__qtjambi_ptr) QPagedPaintDevice::Margins{static_cast<qreal>(left0), static_cast<qreal>(right1), static_cast<qreal>(top2), static_cast<qreal>(bottom3)};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QPagedPaintDevice::Margins::Margins{qreal,qreal,qreal,qreal}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_initialize_1native__Lio_qt_gui_QPagedPaintDevice_00024Margins_2DDDD)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jdouble left0,
 jdouble right1,
 jdouble top2,
 jdouble bottom3)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPagedPaintDevice::Margins::Margins{qreal,qreal,qreal,qreal}")
    QTJAMBI_TRY {
        jvalue arguments[4];
        arguments[0].d = left0;
        arguments[1].d = right1;
        arguments[2].d = top2;
        arguments[3].d = bottom3;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPagedPaintDevice_Margins_qreal_qreal_qreal_qreal, sizeof(QPagedPaintDevice::Margins), typeid(QPagedPaintDevice::Margins), false, &deleter_QPagedPaintDevice_Margins, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPagedPaintDevice::Margins
void __qt_destruct_QPagedPaintDevice_Margins(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPagedPaintDevice::Margins")
    reinterpret_cast<QPagedPaintDevice::Margins*>(ptr)->~Margins();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_setBottom_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble bottom0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->bottom = static_cast<qreal>(bottom0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_bottom_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->bottom;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_setLeft_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble left0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->left = static_cast<qreal>(left0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_left_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->left;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_setRight_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble right0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->right = static_cast<qreal>(right0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_right_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->right;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_setTop_1native_1qreal__JD)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jdouble top0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->top = static_cast<qreal>(top0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jdouble JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_top_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jdouble __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qreal  __qt_value = __qt_this->top;
        __java_return_value = jdouble(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPagedPaintDevice_00024Margins_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPagedPaintDevice::Margins *__qt_this = QtJambiAPI::objectFromNativeId<QPagedPaintDevice::Margins>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPagedPaintDevice_Margins(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPagedPaintDevice::Margins>("QPagedPaintDevice::Margins", "io/qt/gui/QPagedPaintDevice$Margins");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPagedPaintDevice_Margins, {
        ConstructorInfo(&__qt_construct_QPagedPaintDevice_Margins, nullptr)
       ,ConstructorInfo(&__qt_construct_QPagedPaintDevice_Margins_cref_QPagedPaintDevice_Margins, "Lio/qt/gui/QPagedPaintDevice$Margins;")
       ,ConstructorInfo(&__qt_construct_QPagedPaintDevice_Margins_qreal_qreal_qreal_qreal, "DDDD")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPagedPaintDevice_Margins);
    registerMetaType<QPagedPaintDevice::Margins>("QPagedPaintDevice::Margins");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
